
## Summary
Replace pronouns with the nouns they represent.

## Example
```
from depronounize import replace_pronouns

print(replace_pronouns("I went to buy jam, but they were out of it."))
```

## Python Version
Python 3.8.1 was used for testing

